import { GraphQLResolveInfo, GraphQLArgument, GraphQLNamedType } from 'graphql';
import { IMiddlewareFunction } from 'graphql-middleware';
declare type Maybe<T> = T | null;
/**
 *
 * @param type
 * @param info
 *
 * Finds field arguments of the specfied type
 *
 */
export declare function findArgumentsOfType(type: string | GraphQLNamedType, info: GraphQLResolveInfo): Maybe<GraphQLArgument[]>;
/**
 *
 * @param args
 * @param arg
 *
 * Gets the value for argument definition.
 *
 */
export declare function getArgumentValue(args: {
    [key: string]: any;
}, arg: GraphQLArgument): any;
declare type IHandledArg<T> = {
    [key: string]: T | T[];
};
/**
 *
 * @param transform
 * @param usual four resolver parameters
 *
 * Higher-order function that produces a map function over argument definitions
 * of a certain type.  Argument values and lists are transformed
 *
 */
export declare function makeArgumentTransform<T, V>(transform: ITypeArgumentHandler<V, T>, parent: any, args: any, ctx: any, info: any): (argumentDef: GraphQLArgument) => Promise<IHandledArg<T>>;
export declare type ITypeArgumentHandler<V, T> = (value: V | Promise<V>, parent: {}, args: {}, context: {}, info: GraphQLResolveInfo) => Promise<T>;
export interface IConfig<V, T> {
    type: string | GraphQLNamedType;
    transform: ITypeArgumentHandler<V, T>;
}
/**
 *
 * @param config
 *
 * A higher-order function which produces a middleware to transform
 * field arguments of a given type.
 *
 */
export declare function processTypeArgs<V, T>({ type, transform, }: IConfig<V, T>): IMiddlewareFunction;
export declare function visitAllArgs({ transform }: {
    transform: any;
}): IMiddlewareFunction;
export * from './upload';
